Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(685)

Unified Diff: ui/views/layout/grid_layout.h

Issue 2622603003: Hide icons in message center on lock screen (Closed)
Patch Set: Mentioned about height parameter Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/message_center/views/message_center_view_unittest.cc ('k') | ui/views/layout/grid_layout.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/layout/grid_layout.h
diff --git a/ui/views/layout/grid_layout.h b/ui/views/layout/grid_layout.h
index 144fac9830232ee2112dc0983216444594bec266..e6a1ee35496efa63e064a1b845fde3f87f061fa0 100644
--- a/ui/views/layout/grid_layout.h
+++ b/ui/views/layout/grid_layout.h
@@ -129,8 +129,9 @@ class VIEWS_EXPORT GridLayout : public LayoutManager {
void StartRowWithPadding(float vertical_resize, int column_set_id,
float padding_resize, int padding);
- // Starts a new row with the specified column set.
- void StartRow(float vertical_resize, int column_set_id);
+ // Starts a new row with the specified column set and height (0 for
+ // unspecified height).
+ void StartRow(float vertical_resize, int column_set_id, int height = 0);
// Advances past columns. Use this when the current column should not
// contain any views.
« no previous file with comments | « ui/message_center/views/message_center_view_unittest.cc ('k') | ui/views/layout/grid_layout.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698